@@ -1,5 +1,9 @@
 pub mod myblog {
     pub mod proto {
+        pub mod auth {
+            include!("myblog.proto.auth.rs");
+        }
+
         pub mod blog {
             include!("myblog.proto.blog.rs");
         }
