@@ -16,9 +16,9 @@ pub struct Taxonomy {
     /// Valid url string composes with name and id
     #[prost(string, tag = "3")]
     pub slug: std::string::String,
-    /// Term group (e.g. category or tag)
+    /// Type of the term e.g. category or tag
     #[prost(string, tag = "4")]
-    pub term_group: std::string::String,
+    pub r#type: std::string::String,
 }
 /// Piece of content in the blog platform.
 #[derive(Clone, PartialEq, ::prost::Message)]
