@@ -18,13 +18,13 @@ pub struct File {
     pub mime_type: std::string::String,
     /// Name of the cloud object storage provider (e.g. s3, gcp, azure, etc.)
     #[prost(string, tag = "6")]
-    pub cloud_object_storage: std::string::String,
-    /// Amazon S3 region
+    pub provider: std::string::String,
+    /// Region or location where the object has been uploaded
     #[prost(string, tag = "7")]
-    pub s3_region: std::string::String,
-    /// Amazon S3 bucket
+    pub region: std::string::String,
+    /// Name of the bucket
     #[prost(string, tag = "8")]
-    pub s3_bucket: std::string::String,
+    pub bucket: std::string::String,
     /// Date-time that the file was uploaded
     #[prost(message, optional, tag = "9")]
     pub uploaded_at: ::std::option::Option<::prost_types::Timestamp>,
